=== modified file 'bzrlib/tests/blackbox/test_revert.py'
--- bzrlib/tests/blackbox/test_revert.py	2006-03-09 14:40:12 +0000
+++ bzrlib/tests/blackbox/test_revert.py	2006-06-26 17:04:29 +0000
@@ -18,6 +18,7 @@
 
 import os
 
+import bzrlib.osutils
 from bzrlib.tests.blackbox import ExternalBase
 from bzrlib.trace import mutter
 
@@ -72,3 +73,54 @@
         self.assertEqual('', self.capture('status'))
         self.runbzr('revert')
         self.assertEqual('', self.capture('status'))
+
+    def test_revert(self):
+        self.run_bzr('init')
+
+        file('hello', 'wt').write('foo')
+        self.run_bzr('add', 'hello')
+        self.run_bzr('commit', '-m', 'setup', 'hello')
+
+        file('goodbye', 'wt').write('baz')
+        self.run_bzr('add', 'goodbye')
+        self.run_bzr('commit', '-m', 'setup', 'goodbye')
+
+        file('hello', 'wt').write('bar')
+        file('goodbye', 'wt').write('qux')
+        self.run_bzr('revert', 'hello')
+        self.check_file_contents('hello', 'foo')
+        self.check_file_contents('goodbye', 'qux')
+        self.run_bzr('revert')
+        self.check_file_contents('goodbye', 'baz')
+
+        os.mkdir('revertdir')
+        self.run_bzr('add', 'revertdir')
+        self.run_bzr('commit', '-m', 'f')
+        os.rmdir('revertdir')
+        self.run_bzr('revert')
+
+        if bzrlib.osutils.has_symlinks():
+            os.symlink('/unlikely/to/exist', 'symlink')
+            self.run_bzr('add', 'symlink')
+            self.run_bzr('commit', '-m', 'f')
+            os.unlink('symlink')
+            self.run_bzr('revert')
+            self.failUnlessExists('symlink')
+            os.unlink('symlink')
+            os.symlink('a-different-path', 'symlink')
+            self.run_bzr('revert')
+            self.assertEqual('/unlikely/to/exist',
+                             os.readlink('symlink'))
+        else:
+            self.log("skipping revert symlink tests")
+        
+        file('hello', 'wt').write('xyz')
+        self.run_bzr('commit', '-m', 'xyz', 'hello')
+        self.run_bzr('revert', '-r', '1', 'hello')
+        self.check_file_contents('hello', 'foo')
+        self.run_bzr('revert', 'hello')
+        self.check_file_contents('hello', 'xyz')
+        os.chdir('revertdir')
+        self.run_bzr('revert')
+        os.chdir('..')
+

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2006-06-18 03:39:50 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2006-06-26 17:04:29 +0000
@@ -130,56 +130,6 @@
         self.assertEquals(self.capture('unknowns'), '')
         self.assertEquals(file('.bzrignore', 'rU').read(), '*.blah\ngarh\n')
 
-    def test_revert(self):
-        self.runbzr('init')
-
-        file('hello', 'wt').write('foo')
-        self.runbzr('add hello')
-        self.runbzr('commit -m setup hello')
-
-        file('goodbye', 'wt').write('baz')
-        self.runbzr('add goodbye')
-        self.runbzr('commit -m setup goodbye')
-
-        file('hello', 'wt').write('bar')
-        file('goodbye', 'wt').write('qux')
-        self.runbzr('revert hello')
-        self.check_file_contents('hello', 'foo')
-        self.check_file_contents('goodbye', 'qux')
-        self.runbzr('revert')
-        self.check_file_contents('goodbye', 'baz')
-
-        os.mkdir('revertdir')
-        self.runbzr('add revertdir')
-        self.runbzr('commit -m f')
-        os.rmdir('revertdir')
-        self.runbzr('revert')
-
-        if has_symlinks():
-            os.symlink('/unlikely/to/exist', 'symlink')
-            self.runbzr('add symlink')
-            self.runbzr('commit -m f')
-            os.unlink('symlink')
-            self.runbzr('revert')
-            self.failUnlessExists('symlink')
-            os.unlink('symlink')
-            os.symlink('a-different-path', 'symlink')
-            self.runbzr('revert')
-            self.assertEqual('/unlikely/to/exist',
-                             os.readlink('symlink'))
-        else:
-            self.log("skipping revert symlink tests")
-        
-        file('hello', 'wt').write('xyz')
-        self.runbzr('commit -m xyz hello')
-        self.runbzr('revert -r 1 hello')
-        self.check_file_contents('hello', 'foo')
-        self.runbzr('revert hello')
-        self.check_file_contents('hello', 'xyz')
-        os.chdir('revertdir')
-        self.runbzr('revert')
-        os.chdir('..')
-
     def test_mv_modes(self):
         """Test two modes of operation for mv"""
         self.runbzr('init')

